"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _helperPluginUtils = require("@babel/helper-plugin-utils");

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

var arrowRegex = /^\s?(=>|→|throws)/;

var _default = (0, _helperPluginUtils.declare)(function visitor(api) {
  var t = api.types,
      transform = api.transform;
  api.assertVersion(7);

  var assertExpression = function assertExpression(actual, expected, loc, message) {
    var exp = t.callExpression(t.memberExpression(t.identifier('assert'), t.identifier('deepEqual')), [actual, expected].concat(_toConsumableArray(message ? [t.stringLiteral(message)] : [])));
    exp.loc = loc;
    return exp;
  };

  var throwsExpression = function throwsExpression(body, arg, loc, message) {
    var exp = t.callExpression(t.memberExpression(t.identifier('assert'), t.identifier('throws')), [t.arrowFunctionExpression([], body), arg].concat(_toConsumableArray(message ? [t.stringLiteral(message)] : [])));
    exp.loc = loc;
    return exp;
  };

  return {
    visitor: {
      ExpressionStatement: function ExpressionStatement(path, state) {
        var comments = path.node.trailingComments;
        var message = state.opts && state.opts.message;

        if (comments && comments.length > 0 && comments[0].value.match(arrowRegex)) {
          var matches = comments[0].value.match(arrowRegex);

          var _throws = matches[1] === 'throws';

          if (path.node.type !== 'ExpressionStatement') {
            return;
          }

          var child = path.node.expression;
          var commentLoc = comments[0].loc;
          var rawComment = comments[0].value.replace(arrowRegex, '').trim();
          var comment = transform("() => (".concat(rawComment, ")"), {
            ast: true
          }).ast.program.body[0].expression.body;
          path.node.trailingComments = comments.splice(1);

          if (t.isCallExpression(child) && child.callee && child.callee.object && child.callee.object.name === 'console') {
            var code = child.arguments[0];

            if (_throws) {
              path.insertAfter(t.expressionStatement(throwsExpression(code, comment, commentLoc, message)));
            } else {
              path.insertAfter(t.expressionStatement(assertExpression(code, comment, commentLoc, message)));
            }
          } else {
            if (_throws) {
              path.replaceWith(throwsExpression(child, comment, commentLoc, message));
            } else {
              path.replaceWith(assertExpression(child, comment, commentLoc, message));
            }
          }
        }
      }
    }
  };
});

exports["default"] = _default;