"use strict";

var babel = _interopRequireWildcard(require("@babel/core"));

var _prettier = _interopRequireDefault(require("prettier"));

var _assertSimpleTap = _interopRequireDefault(require("assert-simple-tap"));

var _index = _interopRequireDefault(require("./index"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

var format = function format(value) {
  return _prettier["default"].format(value.split(/\s/).join(''));
};

var testGeneration = function testGeneration(code, expectedCode, message) {
  var actualCode = babel.transform(code, {
    babelrc: false,
    plugins: [_index["default"]]
  }).code;

  _assertSimpleTap["default"].equal(format(actualCode), format(expectedCode), message);
};

testGeneration("\na = \"foobar\"\na //=> \"foobar\"\n", "\na = \"foobar\";\nassert.deepEqual(a, \"foobar\");\n", 'add string asserts');
testGeneration("\na = 1;\na //=> 1\n", "\na = 1;\nassert.deepEqual(a, 1);\n", 'should add number asserts');
testGeneration("\na = [1, 2, 3];\na //=> [1, 2, 3]\n", "\na = [1, 2, 3];\nassert.deepEqual(a, [1, 2, 3]);\n", 'should add Array asserts');
testGeneration("\na = { \"a\": 1 }\na //=> {a: 1}\n", "\na = { \"a\": 1 };\nassert.deepEqual(a, { a: 1 });\n", 'should add Object asserts');
testGeneration("\na = { \"a\": 1 }\nconsole.log(a); //=> {a: 1}\n", "\na = { \"a\": 1 };\nconsole.log(a);assert.deepEqual(a, { a: 1 });\n", 'should add console.log asserts');
testGeneration("\na = { \"a\": 1 }\nfoobar(a) //=> {a: 1}\n", "\na = { \"a\": 1 };\nassert.deepEqual(foobar(a), { a: 1 });\n", 'should add functioncall asserts');
testGeneration("\na = { \"foo\": 1 }\na.foo //=> 1\n", "\na = { \"foo\": 1 };\nassert.deepEqual(a.foo, 1);\n", 'should add Object property asserts');
testGeneration("\na = \"foobar\"\na // => \"foobar\"\n", "\na = \"foobar\";\nassert.deepEqual(a, \"foobar\");\n", 'add string asserts with space before arrow');
testGeneration("\na = \"foobar\"\na // \u2192 \"foobar\"\n", "\na = \"foobar\";\nassert.deepEqual(a, \"foobar\");\n", 'add string asserts with space utf8 arrow');
testGeneration("\nconst a = () => {\n  throw new Error('fail');\n};\na() // throws /fail/\n", "\nconst a = () => {\n  throw new Error('fail');\n};\nassert.throws(() => a(), /fail/);\n", 'throws expression');
testGeneration("\nconst a = () => {\n  throw new Error('fail');\n};\na() // throws Error\n", "\nconst a = () => {\n  throw new Error('fail');\n};\nassert.throws(() => a(), Error);\n", 'throws expression');

var testMessageGeneration = function testMessageGeneration(code, expectedCode, message) {
  var actualCode = babel.transform(code, {
    babelrc: false,
    plugins: [[_index["default"], {
      message: message
    }]]
  }).code;

  _assertSimpleTap["default"].equal(format(actualCode), format(expectedCode), message);
};

testMessageGeneration("\na = \"foobar\"\na //=> \"foobar\"\n", "\na = \"foobar\";\nassert.deepEqual(a, \"foobar\", \"add string asserts\");\n", 'add string asserts');
testMessageGeneration("\na = 1;\na //=> 1\n", "\na = 1;\nassert.deepEqual(a, 1, \"should add number asserts\");\n", 'should add number asserts');
testMessageGeneration("\na = [1, 2, 3];\na //=> [1, 2, 3]\n", "\na = [1, 2, 3];\nassert.deepEqual(a, [1, 2, 3], \"should add Array asserts\");\n", 'should add Array asserts');
testMessageGeneration("\na = { \"a\": 1 }\na //=> {a: 1}\n", "\na = { \"a\": 1 };\nassert.deepEqual(a, { a: 1 }, \"should add Object asserts\");\n", 'should add Object asserts');
testMessageGeneration("\na = { \"a\": 1 }\nconsole.log(a); //=> {a: 1}\n", "\na = { \"a\": 1 };\nconsole.log(a);assert.deepEqual(a, { a: 1 }, 'should add console.log asserts');\n", 'should add console.log asserts');
testMessageGeneration("\na = { \"a\": 1 }\nfoobar(a) //=> {a: 1}\n", "\na = { \"a\": 1 };\nassert.deepEqual(foobar(a), { a: 1 }, 'should add functioncall asserts');\n", 'should add functioncall asserts');
testMessageGeneration("\na = { \"foo\": 1 }\na.foo //=> 1\n", "\na = { \"foo\": 1 };\nassert.deepEqual(a.foo, 1, 'should add Object property asserts');\n", 'should add Object property asserts');
testMessageGeneration("\na = \"foobar\"\na // => \"foobar\"\n", "\na = \"foobar\";\nassert.deepEqual(a, \"foobar\", 'add string asserts with space before arrow');\n", 'add string asserts with space before arrow');
testMessageGeneration("\na = \"foobar\"\na // \u2192 \"foobar\"\n", "\na = \"foobar\";\nassert.deepEqual(a, \"foobar\", 'add string asserts with space utf8 arrow');\n", 'add string asserts with space utf8 arrow');
testMessageGeneration("\nconst a = () => {\n  throw new Error('fail');\n};\na() // throws /fail/\n", "\nconst a = () => {\n  throw new Error('fail');\n};\nassert.throws(() => a(), /fail/, 'throws expression');\n", 'throws expression');
testMessageGeneration("\nconst a = () => {\n  throw new Error('fail');\n};\na() // throws Error\n", "\nconst a = () => {\n  throw new Error('fail');\n};\nassert.throws(() => a(), Error, 'throws expression');\n", 'throws expression');